% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/WassersteinPCA.R
\docType{package}
\name{WassersteinPCA-package}
\alias{WassersteinPCA-package}
\title{Package for the computation and visual analysis of Principal Geodesics in the 2-Wasserstein-Space.}
\description{
Visual Principal Component Analysis in the 2-Wasserstein-Space.
}
\details{
This package is designed to easily enable principal component analysis on image datasets.
To this end the images are supposed to be point measures in the 2-Wasserstein-Space and then principal geodesics
in this space are computed. For computations there are four methods available at the moment. The default methods
relies on linearizing the problem and then essentially performing standard PCA. This has the advantage, that it
is fast to compute, hence for everyday application this is the preferred method. Additionally, there are multiple
iterative methods available. Given sufficient iterations, this methods will outperform the default method, but this
is extremely costly and can easily have run times surpassing the 24-hours mark. It is therefore only recommended
in the cases where optimal results are pivotal. \cr \cr
In addition to the computational tools, this package is equipped with two visualization tools. It has the
ability to visualize the computed principal geodesic in a way, that allows for easy visual analysis.
The geodesics are evaluated on a specified time grid and then kernel density estimators are used to obtain
values on a pixel grid. The resulting series of images can either be turned into a series of png-images, that
are generated in the current working directory, or ImageMagick is called to transform this images into
a gif. The second option requires the installation of the animation-package as well as the installation of the
tool ImageMagick. For details on the installation of ImageMagick refer to the manual of the animation package.
(Hint: On some operation system it is necessary to check the box "install legacy utilities" during the installation).
The function that generates this visuals is \link{visual_geodesic}. \cr
The easiest way to use the package is by using the \link{image_pca} function. This is a wrapper function for all the
methods availible in the package. It also allows to create the visual outputs, namely images and animations.\cr \cr
The only case where it is really necessary to call the other functions directly
is the case, that one does not consider image data, but general two-dimensional weighted point measures. In this
case refer to the documentations of the individual functions \link{pca_log}, \link{pca_grid}, \link{pca_ws_tp} and \link{pca_ws}. \cr \cr
This package also offers the option to compute the Wasserstein-Barycenters of general weighted point measures with a support that is
not necessarily a subset of a regular grid. This is necessary to perform PCA, but this feature can also be used
individually by calling the \link{wsbary_cont} function.
}
\references{
Seguy, Vivien and Cuturi, Marco;Principal Geodesic Analysis for Probability Measures under the Optimal Transport Metric;
Advances in Neural Information Processing Systems 28;2015.\cr
Cazelles, Elsa & Seguy, Vivien & Bigot, Jérémie & Cuturi, Marco & Papadakis, Nicolas; Log-PCA versus Geodesic PCA of histograms in the Wasserstein space; SIAM Journal on Scientific Computing. 40; 2017. \cr
A Linear Optimal Transportation Framework for Quantifying and Visualizing Variations in Sets of Images; International Journal of Computer Vision;
Wang, Wei & Slepcev, Dejan & Basu, Saurav & Ozolek, John A. & Rohde, Gustavo K.;2013.\cr
Marco Cuturi and Arnaud Doucet; Fast computation of wasserstein barycenters;
In Proceedings of the 31st International Conference on International Conference on Machine Learning - Volume 32 (ICML'14); 2014.
}
