% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dir_image_pca.R
\name{dir_image_pca}
\alias{dir_image_pca}
\title{Perform Principal Component Analysis on a directory of images.}
\usage{
dir_image_pca(dir, imagetype = "png", imagesize, imagecount = NULL,
  barycenter = NULL, pca.count = 3, method = "log", K = 20,
  steps = 10^-4, lambda = 1, maxiter = 600, error = 10^-7,
  submaxiter = 1000, suberror = 10^-12, substeps = 10^-7,
  sample.points = 100, visual = TRUE, gif = FALSE, H = (1/1000) *
  matrix(c(1, 0, 0, 1), 2, 2), grid.size = 100, file = "RPCA")
}
\arguments{
\item{dir}{A string specifying a directory location that contains images.}

\item{imagetype}{A string specifying the type of images in the directory. The file ending has to be given here.}

\item{imagesize}{A positive integer specifying the size at which the images should be imported. Note that sizes over 100 might requiere
significant amounts of run time and RAM. Even for moderate imagesizes, the computation time might
exceed a single day.}

\item{imagecount}{A positive integer specifying the amount of images from the directory which are to be imported.
If this value is not specified, then all files are imported. Otherwise imagecount images are sampled from the
directory uniformly.}

\item{barycenter}{An N x M Matrix representing the barycenter of the images. If non is specified, then the
one is approximated iteratively.}

\item{pca.count}{An integer specifying the number of principal components to be computed. Has to be lower than
the amount of data images used for the pca.}

\item{method}{A string specifying the method used to compute the pca. The availible options are:\cr \cr
"log" The default method. The image measures are mapped to the tangent space at the barycenter and
standard euclidean is performed on the linearized data. Afterwards the computed principal components are
mapped back to the Wasserstein Space. \cr \cr
"sh": This method computes the principal components via a penalized, projected gradient descent method.
It uses entropy regulazied Sinkhorn distances implemented in the Barycenter package to approximate the
Wasserstein Distances.\cr \cr
"tp" This method computes the principal components via a penalized, projected gradient descent method.
The Wasserstein distance is computed exactly using the implementation in the transport package.\cr \cr
"grid" This method computes the principal components via a projected gradient descent method. It assumes
the data to be supported on the full pixel grid. If the data has indeed mass on nearly all pixels, than
this method is significantly faster, than the "sh" and "tp" method. If the data is rather sparse it is
strongly advised not to use this method. \cr \cr
WARNING: The iterative methods are volatile to the choice of step sizes and maximum iterations. If one
obtains unreasonable results, it is advised to rerun the computation with a smaller step size and
higher number of iterations. Additionally the run time of the iterative methods might exceed a day even for
moderate image sizes. However the performance can be improved greatly by running it on clusters for
parallelization. The "log" method computes results quickly, but the iterative methods yield better results
given sufficient iterations. Hence it is recommended to use "log" for everyday operations and deploy
the other methods when it is important to obtain the best possible results with limited regard to run time.}

\item{K}{Integer used for "sh" and "tp". It specifies the size of the time grid the geodesic is computed
on in every iteration. Choosing this too small negatively impacts convergence, but one should be cautios,
since computation time scales linearly in K.}

\item{steps}{The step size for the gradient descent used in the iterative methods.}

\item{lambda}{The penalty parameter for the "tp" and "sh" methods. If set to zero generalized geodesics
are computed instead of true ones. Otherwise the penalization forces the two velocity fields in the
generalized geodesic to be collinear.}

\item{maxiter}{The maximum number of iterations for the iterative algorithms.}

\item{error}{The threshold in the change in the Wasserstein Distance between two steps at which to stop
the iterative algorithms.}

\item{submaxiter}{The maximum number of iterations for the sub algorithm in the "grid" method.}

\item{suberror}{The threshold of change in each step at which to stop the sub algorithm in the "grid" method.}

\item{substeps}{The step size in the sub algorithm used for the "grid" method.}

\item{sample.points}{The number of time points the geodesic is evaluated and returned.}

\item{visual}{A boolean indicating whether a visual representation of the components should be generated.
If set to TRUE, then a series of png images will be created.}

\item{gif}{A boolean specifying whether the png-images should be used to create a gif, animating the principal
components. This requieres the animation package and imagemagik to be installed and be availible to R.}

\item{H}{The 2x2 bandwidth matrix for the computation of the kernel density estimator.}

\item{grid.size}{The size of the two dimensional grid on which the kde is evaluated.}

\item{file}{String determining the name of the exported files.}
}
\value{
A list of the computed principal components sampled at the specified time points is returned. Each of these
list contains a list of the position matrices of the geodesics at the numbered time points. If the visual parameters
are set to TRUE, then in addition the chosen visualisations will be generated.
}
\description{
Perform Principal Component Analysis on a directory of images.
}
\details{
This is a wrapper function for the different algorithms to perform principal component analysis
on images contained in this package. This function takes a directory, imports the files within the directory
and then calls image_pca with the imported data. Refer to documentation of image_pca for more information.
}
\references{
Seguy, Vivien and Cuturi, Marco;Principal Geodesic Analysis for Probability Measures under the Optimal Transport Metric;
Advances in Neural Information Processing Systems 28;2015.\cr
Cazelles, Elsa & Seguy, Vivien & Bigot, Jérémie & Cuturi, Marco & Papadakis, Nicolas; Log-PCA versus Geodesic PCA of histograms in the Wasserstein space; SIAM Journal on Scientific Computing. 40; 2017. \cr
A Linear Optimal Transportation Framework for Quantifying and Visualizing Variations in Sets of Images; International Journal of Computer Vision;
Wang, Wei & Slepcev, Dejan & Basu, Saurav & Ozolek, John A. & Rohde, Gustavo K.;2013.\cr
Marco Cuturi and Arnaud Doucet; Fast computation of wasserstein barycenters;
In Proceedings of the 31st International Conference on International Conference on Machine Learning - Volume 32 (ICML'14); 2014.
}
