% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/iterative_pca.R
\name{pca_grid}
\alias{pca_grid}
\title{Computes principal components of a data set of weighted point measures in R^d.}
\usage{
pca_grid(data.weight, bary.weight, support, sup_size, t0.grid = 0,
  pca.count = 1, maxiter = 500, submaxiter = 100, tau.t = 10^-8,
  tau.v = 10^-6)
}
\arguments{
\item{data.weight}{A list of NxM matrices containing the weights of the data measures.}

\item{bary.weight}{A NxM matrix containing the weights of the barycenter of the data.}

\item{support}{A (NxM)x2 matrix containing the positions of the grid points. Make sure to align this
properly with the matrix positions of the weights.}

\item{sup_size}{A two-dimensional vector containing the value N and M.}

\item{t0.grid}{A tuning parameter shifting the center of the geodesic. Can remain at default. Might be set
to an vector containing a one dimensional grid centered around zero to obtain a slightly better approximation,
at the cost of a linear scaling in the number of grid points.}

\item{pca.count}{Integer specifying the number of principal geodesic to be computed.}

\item{maxiter}{Integer specifying the maximum number of iterations in the gradient descent.}

\item{submaxiter}{Integer specifying the maximum number of iterationns in the sub-algorithm.}

\item{tau.t}{Real value, specifying the step size in the sub algorithm. This should be reduced, if one
encounters unreasonble results from the gradient descent.}

\item{tau.v}{Real value, specifying the step size in the gradient descent. This should be reduced, if one
encounters unreasonble results from the gradient descent.}
}
\value{
This function returns a list with two entries. The first entry is opt_times. This is a list containing
the optimal time points for each image for each principal geodesic respectively. This is for each pair of a data
measure and a geodesic the t in [0,1], for which the distance between the geodesic and the measure is minimal.\cr
The second entry is opt_velocity. This is a list containing a velocity field for each computed principal geodesic.
They describe the movement of the mass of the barycenter along each geodesic, respectively.
principal geodesic respectively. The positions of the k-th geodesic at time t in [-1,1] is given by
support+t * opt_velocity[[k]]. The weights are given by the weights of the barycenter at the corresponding
support points.
}
\description{
Takes a set of weighted point measures in R^d and their barycenter and computes their principal geodesics based on this.
}
\details{
This functions computes principal geodesics in the 2-Wasserstein space. It takes a set of discretized
or discrete input measures and computes iteratively principal directions using a gradient descent method. It
then returns the velocity fields describing the principal geodesics in the tangent space at the barycenter
of the data. This method requires the data to be supported on a rectangular grid in [0,1]. If one wants to
consider data with a more sparse or less regular support, it should be refered to the pca_ws or image_pca function.
}
\examples{
grid<-WassersteinPCA:::build.grid(14,14)
res<-pca_grid(mnist_zero_mat,mnist_zero_bary_mat,grid,c(14,14))
}
\references{
#' Cazelles, Elsa & Seguy, Vivien & Bigot, Jérémie & Cuturi, Marco & Papadakis, Nicolas; Log-PCA versus Geodesic PCA of histograms in the Wasserstein space;
SIAM Journal on Scientific Computing. 40; 2017.
}
