% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pca_tp.R
\name{pca_ws_tp}
\alias{pca_ws_tp}
\title{Computes principal components of a data set of weighted point measures in R^d.}
\usage{
pca_ws_tp(data.pos, data.weights, bary.pos, bary.weights, stepsize, lambda,
  pca.count, K = 20, max_iter, error)
}
\arguments{
\item{data.pos}{A list of Nxd matrices of data positions.}

\item{data.weights}{A list of N-dim vectors of the data weights.}

\item{bary.pos}{A Nxd matrix of the positions of the barycenter}

\item{bary.weights}{A N-dim vector of the weights of the barycenter}

\item{stepsize}{The step size of the gradient descent algorithm. Note choosing this too high might lead to divergence, but choosing it too small might lead to
long runtimes.}

\item{lambda}{This is a regularisation parameter which is greater or equal to zero. Choosing this greater than zero will lead to a regularization step,
where the velocity fields are forced to be collinear.}

\item{pca.count}{Integer determining the amount of principal components to be computed.}

\item{K}{Integer determining the size of the time grid in the computation. The defauls usually works fine, but in case of bad convergence properties it might
be helpful to increase this paramter. Note that the run time is linear in K.}

\item{max_iter}{Integer specifying the maximal amount of iterations in the gradient descent method.}

\item{error}{The value of change between iterations at which the gradient descent should terminate.}
}
\value{
The function returns an array of the size pca.countx2xNxd, where result[k,1,,] contains the first velocity field of the k-th pca and result[k,2,,] contains
the second velocity field of the k-th pca.
}
\description{
Takes a set of weighted point measures in R^d and their barycenter and computes their principal geodesics based on this.
}
\details{
Let Y be the positions of the barycenter in R^d, then each principal geodesic can be parametrized as G(t)=Y-V1+t(V1+V2) for t in [0,1] and two
velocity fields V1 and V2. This corresponds to the definition of a generalized geodesic. If one wishes to obtain a true geodesic, one can use the regularization
parameter lambda to force the fields to be collinear, but for visual analysis this is often not neccesary. This function takes data sets consisting of sums of
weighted point measures and computes V1 and V2 via projected gradient descent. For each pca that is to be computed the corresponding V1 and V2 are returned.
Since we are restricted to point measures, the velocity fields are simple Nxd matrices here, where each row corresponds to a vector in R^d along which the mass
is transported on the geodesic.\cr
This function is mostly identical to the \link{pca_ws} function. The only difference is, that the former uses an entropy
regularization to approximate the Wasserstein-Distances, while this function explicitly solves the corresponding to optimal
transport problem by calling the transport-package. The pca_ws_tp function is therefore slightly slower, but also
a little more precise.
}
\examples{
res<-pca_ws_tp(mnist_zero[[1]],mnist_zero[[2]],mnist_zero_bary[[1]],mnist_zero_bary[[2]],
10^(-4),0,1,20,400,10^(-6))
visual_geodesic(mnist_zero_bary[[1]],mnist_zero_bary[[2]],res[1,1,,],res[1,2,,])
}
\references{
Seguy, Vivien and Cuturi, Marco; Principal Geodesic Analysis for Probability Measures under the Optimal Transport Metric; Advances in Neural Information Processing Systems 28; 2015.
}
