% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geodesic_visuals.R
\name{visual_geodesic}
\alias{visual_geodesic}
\title{Creates a visualization of a generalized geodesic in the 2-Wasserstein-Space.}
\usage{
visual_geodesic(bary.pos, bary.weights, V1, V2, timesteps = 100,
  H = (1/1000) * matrix(c(1, 0, 0, 1), 2, 2), grid.size = 100,
  create.gif = TRUE, create.images = TRUE, file.name = "RGeodesic",
  delay.time = 20)
}
\arguments{
\item{bary.pos}{Nx2 Matrix of Positions of the barycenter in two dimensional space.}

\item{bary.weights}{A vector of the weights of each position of the barycenter}

\item{V1}{A Nx2 matrix specifying the first velocity field}

\item{V2}{A Nx2 matrix specifying the second velocity field}

\item{timesteps}{The amount of time steps between t=0 and t=1 at which the Geodesic is computed.}

\item{H}{The 2x2 bandwidth matrix for the computation of the kernel density estimator.}

\item{grid.size}{The size of the two dimensional grid on which the kde is evaluated.}

\item{create.gif}{Boolean determining whether the results should be exported as a gif. Note that this requieres the installation of the animation package and imagemagik.}

\item{create.images}{Boolean determining whether the results should be exported as a series of png-images.}

\item{file.name}{String determining the name of the exported files.}

\item{delay.time}{The time between two frames in the generated gif.}
}
\value{
The function returns an array of the size gridsize x gridsize x (2+timesteps) containing the evaluation of the kde on the grid at each timepoint.
If create.image=TRUE, then the function exports the results as a series of png images at the corresponding time steps. If create.gif=TRUE, then it creates a gif
from this images to visualize the transport corresponding to the geodesic. Note that create.gif and create.images operate independent from each other, i.e. you
need to set both values to TRUE if you want both outputs.
}
\description{
Creates a visualization of a general geodesic in the 2-Wasserstein-Space. It is parametrized as Y-V1+t(V1+V2), where Y is the matrix of positions of the
barycenter and V1 and V2 are velocity fields. It creates either a series of images or a gif to visualize the geodesic. The creation of a gif requieres the installation of
Imagemagik and the animation package.
}
\examples{
components<-pca_log(mnist_zero[[2]],mnist_zero[[1]],mnist_zero_bary[[2]],mnist_zero_bary[[1]])
for (c in 1:3){
 V<-components$components[[c]]*sqrt(components$evalues[c])
 name<-paste("RtestPCA","_pcanr_",c,sep="")
 visual_geodesic(mnist_zero_bary[[1]],mnist_zero_bary[[2]],V,V,timesteps = 100,grid.size=28*4,
 create.gif = FALSE,file.name=name)
}
}
