% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bary_cont_multidim.R
\name{wsbary_cont}
\alias{wsbary_cont}
\title{Computes an approximation of the 2-Wasserstein-Barycenter of discrete input measures.}
\usage{
wsbary_cont(data.weights, data.pos, sup_size, maxiter = 50,
  sub_iter = 5, theta = 0.5)
}
\arguments{
\item{data.weights}{A list of vectors specifying the weights of the data measures. Each vector is assumed to
sum to one.}

\item{data.pos}{A list of Mxd matrices, specifying the positions of the data measures. Different measures do
not have to have the same support size and do not need to be supported on some grid.}

\item{sup_size}{A positive integer specifying the size of the support of the approximated barycenter.}

\item{maxiter}{A positive integer specifying the maximum number of iterations in the algorithm.}

\item{sub_iter}{A positive integer specifying the number of iterations in the weight-updates.}

\item{theta}{A real value in [0,1] used as a tuning parameter for the gradient descent.}
}
\value{
The function returns a list with two entries. The first entry contains the positions of the computed
barycenter and the second entry contains the corresponding weights.
}
\description{
This function computes iteratively the best approximation of the data's Wasserstein-Barycenter
supported on a support of a specified size.
}
\examples{
res<-wsbary_cont(mnist_zero[[2]],mnist_zero[[1]],100,30,2)
}
\references{
Marco Cuturi and Arnaud Doucet; Fast computation of wasserstein barycenters;
In Proceedings of the 31st International Conference on International Conference on Machine Learning - Volume 32 (ICML'14); 2014.
}
